import{f as c,a as f}from"./bmn8XlW7.js";import{p as l,e as g,l as u,r as m,t as p,a as v}from"./DpkolLiq.js";import{s as b}from"./DFCveWjv.js";import{d as x,f as h}from"./DxBGAPM1.js";import{p as t}from"./TXeUdaq1.js";import{c as y}from"./SxayRmdi.js";var w=c("<div><!></div>");function z(o,e){l(e,!0);const s={default:"bg-primary text-primary-foreground hover:bg-primary/80",secondary:"bg-secondary text-secondary-foreground hover:bg-secondary/80",destructive:"bg-destructive text-destructive-foreground hover:bg-destructive/80",outline:"text-foreground border",success:"bg-green-500 text-white hover:bg-green-600",warning:"bg-yellow-500 text-white hover:bg-yellow-600"};let a=t(e,"variant",3,"default"),n=t(e,"class",3,"");var r=w(),i=g(r);b(i,()=>e.children??u),m(r),p(d=>h(r,1,d),[()=>x(y("inline-flex items-center rounded-full border px-2.5 py-0.5 text-xs font-semibold transition-colors focus:outline-none focus:ring-2 focus:ring-ring focus:ring-offset-2",s[a()],n()))]),f(o,r),v()}export{z as B};
