import{c as n,a as i}from"./bmn8XlW7.js";import"./EMQoTJgY.js";import{f as p}from"./DpkolLiq.js";import{I as l,s as m}from"./DxBGAPM1.js";import{l as d,s as f}from"./TXeUdaq1.js";function y(o,r){const e=d(r,["children","$$slots","$$events","$$legacy"]);/**
 * @license lucide-svelte v0.469.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const t=[["path",{d:"M19 21v-2a4 4 0 0 0-4-4H9a4 4 0 0 0-4 4v2"}],["circle",{cx:"12",cy:"7",r:"4"}]];l(o,f({name:"user"},()=>e,{get iconNode(){return t},children:(a,$)=>{var s=n(),c=p(s);m(c,r,"default",{}),i(a,s)},$$slots:{default:!0}}))}export{y as U};
