import{c as p,a as i}from"./bmn8XlW7.js";import"./EMQoTJgY.js";import{f as m}from"./DpkolLiq.js";import{I as c,s as d}from"./DxBGAPM1.js";import{l,s as f}from"./TXeUdaq1.js";function x(s,o){const r=l(o,["children","$$slots","$$events","$$legacy"]);/**
 * @license lucide-svelte v0.469.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const e=[["path",{d:"M18 6 6 18"}],["path",{d:"m6 6 12 12"}]];c(s,f({name:"x"},()=>r,{get iconNode(){return e},children:(a,$)=>{var t=p(),n=m(t);d(n,o,"default",{}),i(a,t)},$$slots:{default:!0}}))}export{x as X};
