import{c as i,a as d}from"./bmn8XlW7.js";import"./EMQoTJgY.js";import{f as l}from"./DpkolLiq.js";import{I as p,s as c}from"./DxBGAPM1.js";import{l as m,s as f}from"./TXeUdaq1.js";function u(o,r){const a=m(r,["children","$$slots","$$events","$$legacy"]);/**
 * @license lucide-svelte v0.469.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const s=[["line",{x1:"22",x2:"2",y1:"12",y2:"12"}],["path",{d:"M5.45 5.11 2 12v6a2 2 0 0 0 2 2h16a2 2 0 0 0 2-2v-6l-3.45-6.89A2 2 0 0 0 16.76 4H7.24a2 2 0 0 0-1.79 1.11z"}],["line",{x1:"6",x2:"6.01",y1:"16",y2:"16"}],["line",{x1:"10",x2:"10.01",y1:"16",y2:"16"}]];p(o,f({name:"hard-drive"},()=>a,{get iconNode(){return s},children:(t,$)=>{var e=i(),n=l(e);c(n,r,"default",{}),d(t,e)},$$slots:{default:!0}}))}export{u as H};
