import{c as m,a as n}from"../chunks/bmn8XlW7.js";import{f as p}from"../chunks/DpkolLiq.js";import{s as e}from"../chunks/DFCveWjv.js";function c(r,a){var o=m(),t=p(o);e(t,()=>a.children),n(r,o)}export{c as component};
