var G=t=>{throw TypeError(t)};var $=(t,e,n)=>e.has(t)||G("Cannot "+n);var g=(t,e,n)=>($(t,e,"read from private field"),n?n.call(t):e.get(t)),w=(t,e,n)=>e.has(t)?G("Cannot add the same private member more than once"):e instanceof WeakSet?e.add(t):e.set(t,n),O=(t,e,n,r)=>($(t,e,"write to private field"),r?r.call(t,n):e.set(t,n),n);import{u as B,I as rt,s as st}from"./DxBGAPM1.js";import{s as _,b as q,c as A,g as l,h as Z,K as ot,u as H,k as it,bh as ut,bi as X,bj as ct,H as at,p as ft,f as U,a as lt,l as dt}from"./DpkolLiq.js";import{c as j,a as L}from"./bmn8XlW7.js";import{s as pt}from"./DFCveWjv.js";import{i as mt,l as ht,s as Et}from"./TXeUdaq1.js";import{j as gt,o as x}from"./pfhwnV1O.js";import"./EMQoTJgY.js";function bt(t){return typeof t=="function"}function At(t){return t!==null&&typeof t=="object"}const yt=["string","number","bigint","boolean"];function D(t){return t==null||yt.includes(typeof t)?!0:Array.isArray(t)?t.every(e=>D(e)):typeof t=="object"?Object.getPrototypeOf(t)===Object.prototype:!1}const N=Symbol("box"),k=Symbol("is-writable");function St(t){return At(t)&&N in t}function wt(t){return m.isBox(t)&&k in t}function m(t){let e=_(q(t));return{[N]:!0,[k]:!0,get current(){return l(e)},set current(n){A(e,n,!0)}}}function vt(t,e){const n=Z(t);return e?{[N]:!0,[k]:!0,get current(){return l(n)},set current(r){e(r)}}:{[N]:!0,get current(){return t()}}}function Ot(t){return m.isBox(t)?t:bt(t)?m.with(t):m(t)}function Tt(t){return Object.entries(t).reduce((e,[n,r])=>m.isBox(r)?(m.isWritableBox(r)?Object.defineProperty(e,n,{get(){return r.current},set(o){r.current=o}}):Object.defineProperty(e,n,{get(){return r.current}}),e):Object.assign(e,{[n]:r}),{})}function It(t){return m.isWritableBox(t)?{[N]:!0,get current(){return t.current}}:t}m.from=Ot;m.with=vt;m.flatten=Tt;m.readonly=It;m.isBox=St;m.isWritableBox=wt;function _t(...t){return function(e){var n;for(const r of t)if(r){if(e.defaultPrevented)return;typeof r=="function"?r.call(this,e):(n=r.current)==null||n.call(this,e)}}}var V=/\/\*[^*]*\*+([^/*][^*]*\*+)*\//g,xt=/\n/g,Nt=/^\s*/,Ct=/^(\*?[-#/*\\\w]+(\[[0-9a-z_-]+\])?)\s*/,Ft=/^:\s*/,Pt=/^((?:'(?:\\'|.)*?'|"(?:\\"|.)*?"|\([^)]*?\)|[^};])+)/,Rt=/^[;\s]*/,Mt=/^\s+|\s+$/g,Wt=`
`,K="/",Y="*",v="",Bt="comment",Ut="declaration";function jt(t,e){if(typeof t!="string")throw new TypeError("First argument must be a string");if(!t)return[];e=e||{};var n=1,r=1;function o(c){var u=c.match(xt);u&&(n+=u.length);var b=c.lastIndexOf(Wt);r=~b?c.length-b:r+c.length}function s(){var c={line:n,column:r};return function(u){return u.position=new i(c),p(),u}}function i(c){this.start=c,this.end={line:n,column:r},this.source=e.source}i.prototype.content=t;function a(c){var u=new Error(e.source+":"+n+":"+r+": "+c);if(u.reason=c,u.filename=e.source,u.line=n,u.column=r,u.source=t,!e.silent)throw u}function d(c){var u=c.exec(t);if(u){var b=u[0];return o(b),t=t.slice(b.length),u}}function p(){d(Nt)}function h(c){var u;for(c=c||[];u=S();)u!==!1&&c.push(u);return c}function S(){var c=s();if(!(K!=t.charAt(0)||Y!=t.charAt(1))){for(var u=2;v!=t.charAt(u)&&(Y!=t.charAt(u)||K!=t.charAt(u+1));)++u;if(u+=2,v===t.charAt(u-1))return a("End of comment missing");var b=t.slice(2,u-2);return r+=2,o(b),t=t.slice(u),r+=2,c({type:Bt,comment:b})}}function f(){var c=s(),u=d(Ct);if(u){if(S(),!d(Ft))return a("property missing ':'");var b=d(Pt),nt=c({type:Ut,property:z(u[0].replace(V,v)),value:b?z(b[0].replace(V,v)):v});return d(Rt),nt}}function E(){var c=[];h(c);for(var u;u=f();)u!==!1&&(c.push(u),h(c));return c}return p(),E()}function z(t){return t?t.replace(Mt,v):v}function Lt(t,e){let n=null;if(!t||typeof t!="string")return n;const r=jt(t),o=typeof e=="function";return r.forEach(s=>{if(s.type!=="declaration")return;const{property:i,value:a}=s;o?e(i,a,s):a&&(n=n||{},n[i]=a)}),n}const Dt=/\d/,Ht=["-","_","/","."];function kt(t=""){if(!Dt.test(t))return t!==t.toLowerCase()}function Gt(t){const e=[];let n="",r,o;for(const s of t){const i=Ht.includes(s);if(i===!0){e.push(n),n="",r=void 0;continue}const a=kt(s);if(o===!1){if(r===!1&&a===!0){e.push(n),n=s,r=a;continue}if(r===!0&&a===!1&&n.length>1){const d=n.at(-1);e.push(n.slice(0,Math.max(0,n.length-1))),n=d+s,r=a;continue}}n+=s,r=a,o=i}return e.push(n),e}function J(t){return t?Gt(t).map(e=>Xt(e)).join(""):""}function $t(t){return Vt(J(t||""))}function Xt(t){return t?t[0].toUpperCase()+t.slice(1):""}function Vt(t){return t?t[0].toLowerCase()+t.slice(1):""}function M(t){if(!t)return{};const e={};function n(r,o){if(r.startsWith("-moz-")||r.startsWith("-webkit-")||r.startsWith("-ms-")||r.startsWith("-o-")){e[J(r)]=o;return}if(r.startsWith("--")){e[r]=o;return}e[$t(r)]=o}return Lt(t,n),e}function Q(...t){return(...e)=>{for(const n of t)typeof n=="function"&&n(...e)}}function Kt(t,e){const n=RegExp(t,"g");return r=>{if(typeof r!="string")throw new TypeError(`expected an argument of type string, but got ${typeof r}`);return r.match(n)?r.replace(n,e):r}}const Yt=Kt(/[A-Z]/,t=>`-${t.toLowerCase()}`);function zt(t){if(!t||typeof t!="object"||Array.isArray(t))throw new TypeError(`expected an argument of type object, but got ${typeof t}`);return Object.keys(t).map(e=>`${Yt(e)}: ${t[e]};`).join(`
`)}function tt(t={}){return zt(t).replace(`
`," ")}const qt={position:"absolute",width:"1px",height:"1px",padding:"0",margin:"-1px",overflow:"hidden",clip:"rect(0, 0, 0, 0)",whiteSpace:"nowrap",borderWidth:"0",transform:"translateX(-100%)"},Ee=tt(qt);function Zt(t){var e;return t.length>2&&t.startsWith("on")&&t[2]===((e=t[2])==null?void 0:e.toLowerCase())}function ge(...t){const e={...t[0]};for(let n=1;n<t.length;n++){const r=t[n];for(const o in r){const s=e[o],i=r[o],a=typeof s=="function",d=typeof i=="function";if(a&&Zt(o)){const p=s,h=i;e[o]=_t(p,h)}else if(a&&d)e[o]=Q(s,i);else if(o==="class"){const p=D(s),h=D(i);p&&h?e[o]=B(s,i):p?e[o]=B(s):h&&(e[o]=B(i))}else if(o==="style"){const p=typeof s=="object",h=typeof i=="object",S=typeof s=="string",f=typeof i=="string";if(p&&h)e[o]={...s,...i};else if(p&&f){const E=M(i);e[o]={...s,...E}}else if(S&&h){const E=M(s);e[o]={...E,...i}}else if(S&&f){const E=M(s),c=M(i);e[o]={...E,...c}}else p?e[o]=s:h?e[o]=i:S?e[o]=s:f&&(e[o]=i)}else e[o]=i!==void 0?i:s}}return typeof e.style=="object"&&(e.style=tt(e.style).replaceAll(`
`," ")),e.hidden!==!0&&(e.hidden=void 0,delete e.hidden),e.disabled!==!0&&(e.disabled=void 0,delete e.disabled),e}const Jt=typeof window<"u"?window:void 0;function Qt(t){let e=t.activeElement;for(;e!=null&&e.shadowRoot;){const n=e.shadowRoot.activeElement;if(n===e)break;e=n}return e}var I,C;class te{constructor(e={}){w(this,I);w(this,C);const{window:n=Jt,document:r=n==null?void 0:n.document}=e;n!==void 0&&(O(this,I,r),O(this,C,gt(o=>{const s=x(n,"focusin",o),i=x(n,"focusout",o);return()=>{s(),i()}})))}get current(){var e;return(e=g(this,C))==null||e.call(this),g(this,I)?Qt(g(this,I)):null}}I=new WeakMap,C=new WeakMap;new te;function ee(t,e){switch(t){case"post":H(e);break;case"pre":ot(e);break}}function et(t,e,n,r={}){const{lazy:o=!1}=r;let s=!o,i=Array.isArray(t)?[]:void 0;ee(e,()=>{const a=Array.isArray(t)?t.map(p=>p()):t();if(!s){s=!0,i=a;return}const d=it(()=>n(a,i));return i=a,d})}function T(t,e,n){et(t,"post",e,n)}function ne(t,e,n){et(t,"pre",e,n)}T.pre=ne;var F,P;class re{constructor(e){w(this,F,_(void 0));w(this,P);H(()=>{A(g(this,F),g(this,P),!0),O(this,P,e())})}get current(){return l(g(this,F))}}F=new WeakMap,P=new WeakMap;var R,y;class be{constructor(e){w(this,R);w(this,y);O(this,R,e),O(this,y,Symbol(e))}get key(){return g(this,y)}exists(){return ut(g(this,y))}get(){const e=X(g(this,y));if(e===void 0)throw new Error(`Context "${g(this,R)}" not found`);return e}getOr(e){const n=X(g(this,y));return n===void 0?e:n}set(e){return ct(g(this,y),e)}}R=new WeakMap,y=new WeakMap;function se(t){H(()=>()=>{t()})}function Ae({id:t,ref:e,deps:n=()=>!0,onRefChange:r,getRootNode:o}){T([()=>t.current,n],([s])=>{const i=(o==null?void 0:o())??document,a=i==null?void 0:i.getElementById(s);a?e.current=a:e.current=null,r==null||r(e.current)}),se(()=>{e.current=null,r==null||r(null)})}function oe(t){at().then(t)}function ye(t){return t?"open":"closed"}function Se(t){return t?"true":"false"}function we(t){return t?"true":"false"}function ve(t){return t?"":void 0}function Oe(t){return t?"true":"false"}function Te(t){return t}function Ie(t){return t}function _e(t){return t?!0:void 0}function xe(t){return t?!0:void 0}function Ne(t){return t?!0:void 0}const Ce="Alt",Fe="ArrowDown",Pe="ArrowLeft",Re="ArrowRight",Me="ArrowUp",We="Backspace",Be="CapsLock",Ue="Control",je="End",Le="Enter",De="Escape",He="F1",ke="F10",Ge="F11",$e="F12",Xe="F2",Ve="F3",Ke="F4",Ye="F5",ze="F6",qe="F7",Ze="F8",Je="F9",Qe="Home",tn="Meta",en="PageDown",nn="PageUp",rn="Shift",sn=" ",on="Tab";globalThis.bitsIdCounter??(globalThis.bitsIdCounter={current:0});function un(t="bits"){return globalThis.bitsIdCounter.current++,`${t}-${globalThis.bitsIdCounter.current}`}function cn(){}function ie(t,e){const n=m(t);function r(s){return e[n.current][s]??n.current}return{state:n,dispatch:s=>{n.current=r(s)}}}function ue(t,e){let n=_(q({})),r=_("none");const o=t.current?"mounted":"unmounted";let s=_(null);const i=new re(()=>t.current);T([()=>e.current,()=>t.current],([f,E])=>{!f||!E||oe(()=>{A(s,document.getElementById(f),!0)})});const{state:a,dispatch:d}=ie(o,{mounted:{UNMOUNT:"unmounted",ANIMATION_OUT:"unmountSuspended"},unmountSuspended:{MOUNT:"mounted",ANIMATION_END:"unmounted"},unmounted:{MOUNT:"mounted"}});T(()=>t.current,f=>{if(l(s)||A(s,document.getElementById(e.current),!0),!l(s)||!(f!==i.current))return;const c=l(r),u=W(l(s));f?d("MOUNT"):u==="none"||l(n).display==="none"?d("UNMOUNT"):d(i&&c!==u?"ANIMATION_OUT":"UNMOUNT")});function p(f){if(l(s)||A(s,document.getElementById(e.current),!0),!l(s))return;const E=W(l(s)),c=E.includes(f.animationName)||E==="none";f.target===l(s)&&c&&d("ANIMATION_END")}function h(f){l(s)||A(s,document.getElementById(e.current),!0),l(s)&&f.target===l(s)&&A(r,W(l(s)),!0)}T(()=>a.current,()=>{if(l(s)||A(s,document.getElementById(e.current),!0),!l(s))return;const f=W(l(s));A(r,a.current==="mounted"?f:"none",!0)}),T(()=>l(s),f=>{if(f)return A(n,getComputedStyle(f),!0),Q(x(f,"animationstart",h),x(f,"animationcancel",p),x(f,"animationend",p))});const S=Z(()=>["mounted","unmountSuspended"].includes(a.current));return{get current(){return l(S)}}}function W(t){return t&&getComputedStyle(t).animationName||"none"}function an(t,e){ft(e,!0);const n=ue(m.with(()=>e.present),m.with(()=>e.id));var r=j(),o=U(r);{var s=i=>{var a=j(),d=U(a);pt(d,()=>e.presence??dt,()=>({present:n})),L(i,a)};mt(o,i=>{(e.forceMount||e.present||n.current)&&i(s)})}L(t,r),lt()}function fn(t,e){const n=ht(e,["children","$$slots","$$events","$$legacy"]);/**
 * @license lucide-svelte v0.469.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const r=[["path",{d:"m6 9 6 6 6-6"}]];rt(t,Et({name:"chevron-down"},()=>n,{get iconNode(){return r},children:(o,s)=>{var i=j(),a=U(i);st(a,e,"default",{}),L(o,i)},$$slots:{default:!0}}))}export{tt as $,Me as A,Je as B,fn as C,ke as D,je as E,He as F,Ge as G,Qe as H,$e as I,We as J,nn as K,en as L,tn as M,ve as N,we as O,an as P,se as Q,re as R,sn as S,on as T,Ne as U,xe as V,Q as W,Te as X,Se as Y,Jt as Z,M as _,Re as a,_t as a0,Ie as a1,Oe as a2,_e as a3,Pe as b,Fe as c,m as d,be as e,Le as f,ye as g,un as h,oe as i,De as j,rn as k,Be as l,ge as m,cn as n,Ue as o,Ce as p,Xe as q,Ve as r,Ee as s,Ke as t,Ae as u,Ye as v,T as w,ze as x,qe as y,Ze as z};
