import{A as _,ai as o,aj as N,Z as p,ak as h,al as w,o as f,C as i,am as C,v as y,an as A,V as x}from"./DpkolLiq.js";function E(r){var a=document.createElement("template");return a.innerHTML=r.replaceAll("<!>","<!---->"),a.content}function t(r,a){var e=p;e.nodes===null&&(e.nodes={start:r,end:a,a:null,t:null})}function L(r,a){var e=(a&h)!==0,l=(a&w)!==0,s,m=!r.startsWith("<!>");return()=>{if(f)return t(i,null),i;s===void 0&&(s=E(m?r:"<!>"+r),e||(s=o(s)));var n=l||N?document.importNode(s,!0):s.cloneNode(!0);if(e){var v=o(n),d=n.lastChild;t(v,d)}else t(n,n);return n}}function F(r,a,e="svg"){var l=!r.startsWith("<!>"),s=(a&h)!==0,m=`<${e}>${l?r:"<!>"+r}</${e}>`,n;return()=>{if(f)return t(i,null),i;if(!n){var v=E(m),d=o(v);if(s)for(n=document.createDocumentFragment();o(d);)n.appendChild(o(d));else n=o(d)}var u=n.cloneNode(!0);if(s){var g=o(u),T=u.lastChild;t(g,T)}else t(u,u);return u}}function O(r,a){return F(r,a,"svg")}function P(r=""){if(!f){var a=_(r+"");return t(a,a),a}var e=i;return e.nodeType!==A&&(e.before(e=_()),x(e)),t(e,e),e}function R(){if(f)return t(i,null),i;var r=document.createDocumentFragment(),a=document.createComment(""),e=_();return r.append(a,e),t(a,e),r}function b(r,a){if(f){var e=p;((e.f&C)===0||e.nodes.end===null)&&(e.nodes.end=i),y();return}r!==null&&r.before(a)}const M="5";var c;typeof window<"u"&&((c=window.__svelte??(window.__svelte={})).v??(c.v=new Set)).add(M);export{b as a,t as b,R as c,E as d,O as e,L as f,P as t};
