import{c as d,a as h}from"./bmn8XlW7.js";import"./EMQoTJgY.js";import{f as i}from"./DpkolLiq.js";import{I as n,s as c}from"./DxBGAPM1.js";import{l as m,s as l}from"./TXeUdaq1.js";function _(r,t){const o=m(t,["children","$$slots","$$events","$$legacy"]);/**
 * @license lucide-svelte v0.469.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const e=[["rect",{width:"16",height:"16",x:"4",y:"4",rx:"2"}],["rect",{width:"6",height:"6",x:"9",y:"9",rx:"1"}],["path",{d:"M15 2v2"}],["path",{d:"M15 20v2"}],["path",{d:"M2 15h2"}],["path",{d:"M2 9h2"}],["path",{d:"M20 15h2"}],["path",{d:"M20 9h2"}],["path",{d:"M9 2v2"}],["path",{d:"M9 20v2"}]];n(r,l({name:"cpu"},()=>o,{get iconNode(){return e},children:(s,f)=>{var a=d(),p=i(a);c(p,t,"default",{}),h(s,a)},$$slots:{default:!0}}))}export{_ as C};
