import{m as M,o as T,v as $,E as j,R as C,T as F,U as Z,V as q,W as y,Q as z,X as G,l as m,Y as H,g as v,c as D,Z as O,_ as Q,$ as w,a0 as V,a1 as N,O as W,a2 as X,b as J,a3 as k,a4 as ee,a5 as I,a6 as A,a7 as re,k as ne,a8 as se,a9 as ie,aa as ue,ab as _,S as L,ac as B,ad as te}from"./DpkolLiq.js";import{B as ae}from"./Dt_5EWjC.js";import{s as fe,g as le}from"./CJbqisBi.js";function Pe(e,r,s=!1){T&&$();var n=new ae(e),i=s?j:0;function t(f,a){if(T){const b=C(e)===F;if(f===b){var l=Z();q(l),n.anchor=l,y(!1),n.ensure(f,a),y(!0);return}}n.ensure(f,a)}M(()=>{var f=!1;r((a,l=!0)=>{f=!0,t(l,a)}),f||t(!1,null)},i)}let P=!1,x=Symbol();function Se(e,r,s){const n=s[r]??(s[r]={store:null,source:H(void 0),unsubscribe:m});if(n.store!==e&&!(x in s))if(n.unsubscribe(),n.store=e??null,e==null)n.source.v=void 0,n.unsubscribe=m;else{var i=!0;n.unsubscribe=fe(e,t=>{i?n.source.v=t:D(n.source,t)}),i=!1}return e&&x in s?le(e):v(n.source)}function we(){const e={};function r(){z(()=>{for(var s in e)e[s].unsubscribe();G(e,x,{enumerable:!1,value:!0})})}return[e,r]}function oe(e){var r=P;try{return P=!1,[e(),P]}finally{P=r}}const ce={get(e,r){if(!e.exclude.includes(r))return e.props[r]},set(e,r){return!1},getOwnPropertyDescriptor(e,r){if(!e.exclude.includes(r)&&r in e.props)return{enumerable:!0,configurable:!0,value:e.props[r]}},has(e,r){return e.exclude.includes(r)?!1:r in e.props},ownKeys(e){return Reflect.ownKeys(e.props).filter(r=>!e.exclude.includes(r))}};function xe(e,r,s){return new Proxy({props:e,exclude:r},ce)}const pe={get(e,r){if(!e.exclude.includes(r))return v(e.version),r in e.special?e.special[r]():e.props[r]},set(e,r,s){if(!(r in e.special)){var n=O;try{A(e.parent_effect),e.special[r]=_e({get[r](){return e.props[r]}},r,N)}finally{A(n)}}return e.special[r](s),I(e.version),!0},getOwnPropertyDescriptor(e,r){if(!e.exclude.includes(r)&&r in e.props)return{enumerable:!0,configurable:!0,value:e.props[r]}},deleteProperty(e,r){return e.exclude.includes(r)||(e.exclude.push(r),I(e.version)),!0},has(e,r){return e.exclude.includes(r)?!1:r in e.props},ownKeys(e){return Reflect.ownKeys(e.props).filter(r=>!e.exclude.includes(r))}};function Oe(e,r){return new Proxy({props:e,exclude:r,special:{},version:Q(0),parent_effect:O},pe)}const de={get(e,r){let s=e.props.length;for(;s--;){let n=e.props[s];if(_(n)&&(n=n()),typeof n=="object"&&n!==null&&r in n)return n[r]}},set(e,r,s){let n=e.props.length;for(;n--;){let i=e.props[n];_(i)&&(i=i());const t=w(i,r);if(t&&t.set)return t.set(s),!0}return!1},getOwnPropertyDescriptor(e,r){let s=e.props.length;for(;s--;){let n=e.props[s];if(_(n)&&(n=n()),typeof n=="object"&&n!==null&&r in n){const i=w(n,r);return i&&!i.configurable&&(i.configurable=!0),i}}},has(e,r){if(r===L||r===B)return!1;for(let s of e.props)if(_(s)&&(s=s()),s!=null&&r in s)return!0;return!1},ownKeys(e){const r=[];for(let s of e.props)if(_(s)&&(s=s()),!!s){for(const n in s)r.includes(n)||r.push(n);for(const n of Object.getOwnPropertySymbols(s))r.includes(n)||r.push(n)}return r}};function Ee(...e){return new Proxy({props:e},de)}function _e(e,r,s,n){var R;var i=!se||(s&ie)!==0,t=(s&re)!==0,f=(s&te)!==0,a=n,l=!0,b=()=>(l&&(l=!1,a=f?ne(n):n),a),c;if(t){var U=L in e||B in e;c=((R=w(e,r))==null?void 0:R.set)??(U&&r in e?u=>e[r]=u:void 0)}var p,E=!1;t?[p,E]=oe(()=>e[r]):p=e[r],p===void 0&&n!==void 0&&(p=b(),c&&(i&&V(),c(p)));var o;if(i?o=()=>{var u=e[r];return u===void 0?b():(l=!0,u)}:o=()=>{var u=e[r];return u!==void 0&&(a=void 0),u===void 0?a:u},i&&(s&N)===0)return o;if(c){var Y=e.$$legacy;return(function(u,h){return arguments.length>0?((!i||!h||Y||E)&&c(h?o():u),u):o()})}var S=!1,d=((s&ue)!==0?W:X)(()=>(S=!1,o()));t&&v(d);var K=O;return(function(u,h){if(arguments.length>0){const g=h?v(d):i&&t?J(u):u;return D(d,g),S=!0,a!==void 0&&(a=g),u}return k&&S||(K.f&ee)!==0?d.v:v(d)})}export{we as a,Se as b,Pe as i,Oe as l,_e as p,xe as r,Ee as s};
