import{G as u,w as t,H as k,k as m,j as _,o as h,I as $,f as b}from"./DpkolLiq.js";import{c as y,a as E}from"./bmn8XlW7.js";import"./EMQoTJgY.js";import{I as S,s as I}from"./DxBGAPM1.js";import{l as C,s as L}from"./TXeUdaq1.js";function z(e,a,o=a){var c=new WeakSet;u(e,"input",async r=>{var l=r?e.defaultValue:e.value;if(l=f(e)?n(l):l,o(l),t!==null&&c.add(t),await k(),l!==(l=a())){var d=e.selectionStart,s=e.selectionEnd,i=e.value.length;if(e.value=l??"",s!==null){var v=e.value.length;d===s&&s===i&&v>i?(e.selectionStart=v,e.selectionEnd=v):(e.selectionStart=d,e.selectionEnd=Math.min(s,v))}}}),(h&&e.defaultValue!==e.value||m(a)==null&&e.value)&&(o(f(e)?n(e.value):e.value),t!==null&&c.add(t)),_(()=>{var r=a();if(e===document.activeElement){var l=$??t;if(c.has(l))return}f(e)&&r===n(e.value)||e.type==="date"&&!r&&!e.value||r!==e.value&&(e.value=r??"")})}function B(e,a,o=a){u(e,"change",c=>{var r=c?e.defaultChecked:e.checked;o(r)}),(h&&e.defaultChecked!==e.checked||m(a)==null)&&o(e.checked),_(()=>{var c=a();e.checked=!!c})}function f(e){var a=e.type;return a==="number"||a==="range"}function n(e){return e===""?null:+e}function G(e,a){const o=C(a,["children","$$slots","$$events","$$legacy"]);/**
 * @license lucide-svelte v0.469.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const c=[["path",{d:"M21 12a9 9 0 1 1-6.219-8.56"}]];S(e,L({name:"loader-circle"},()=>o,{get iconNode(){return c},children:(r,l)=>{var d=y(),s=b(d);I(s,a,"default",{}),E(r,d)},$$slots:{default:!0}}))}export{G as L,B as a,z as b};
