import{f as a,a as s}from"../chunks/bmn8XlW7.js";import{e as n,r as i}from"../chunks/DpkolLiq.js";import{s as l}from"../chunks/DFCveWjv.js";/* empty css                */const c=!1,m=!1,y=Object.freeze(Object.defineProperty({__proto__:null,prerender:m,ssr:c},Symbol.toStringTag,{value:"Module"}));var p=a('<div class="min-h-screen bg-gray-50 dark:bg-gray-900 flex items-center justify-center"><!></div>');function _(r,o){var e=p(),t=n(e);l(t,()=>o.children),i(e),s(r,e)}export{_ as component,y as universal};
