import{f as h,a as g}from"../chunks/bmn8XlW7.js";import{i as d}from"../chunks/EMQoTJgY.js";import{p as l,f as v,t as _,a as x,e as s,r as o,d as $}from"../chunks/DpkolLiq.js";import{s as p}from"../chunks/pfhwnV1O.js";import{s as k,p as m}from"../chunks/C2ETuzsT.js";const b={get error(){return m.error},get status(){return m.status}};k.updated.check;const f=b;var E=h("<h1> </h1> <p> </p>",1);function A(i,n){l(n,!1),d();var t=E(),r=v(t),c=s(r,!0);o(r);var a=$(r,2),u=s(a,!0);o(a),_(()=>{var e;p(c,f.status),p(u,(e=f.error)==null?void 0:e.message)}),g(i,t),x()}export{A as component};
