import{c as i,a as c}from"./bmn8XlW7.js";import"./EMQoTJgY.js";import{f as p}from"./DpkolLiq.js";import{I as m,s as d}from"./DxBGAPM1.js";import{l,s as f}from"./TXeUdaq1.js";function x(s,r){const t=l(r,["children","$$slots","$$events","$$legacy"]);/**
 * @license lucide-svelte v0.469.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const e=[["rect",{width:"18",height:"18",x:"3",y:"3",rx:"2"}]];m(s,f({name:"square"},()=>t,{get iconNode(){return e},children:(a,$)=>{var o=i(),n=p(o);d(n,r,"default",{}),c(a,o)},$$slots:{default:!0}}))}export{x as S};
