import{j as u,Q as m,f as i}from"./DpkolLiq.js";import{c,a as p}from"./bmn8XlW7.js";import"./EMQoTJgY.js";import{I as $,s as f}from"./DxBGAPM1.js";import{l,s as h}from"./TXeUdaq1.js";function b(a,t,o,s,r){var e=()=>{s(o[a])};o.addEventListener(t,e),r?u(()=>{o[a]=r()}):e(),(o===document.body||o===window||o===document)&&m(()=>{o.removeEventListener(t,e)})}function N(a,t){const o=l(t,["children","$$slots","$$events","$$legacy"]);/**
 * @license lucide-svelte v0.469.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const s=[["rect",{width:"8",height:"4",x:"8",y:"2",rx:"1",ry:"1"}],["path",{d:"M16 4h2a2 2 0 0 1 2 2v14a2 2 0 0 1-2 2H6a2 2 0 0 1-2-2V6a2 2 0 0 1 2-2h2"}]];$(a,h({name:"clipboard"},()=>o,{get iconNode(){return s},children:(r,e)=>{var n=c(),d=i(n);f(d,t,"default",{}),p(r,n)},$$slots:{default:!0}}))}function x(a,t){const o=l(t,["children","$$slots","$$events","$$legacy"]);/**
 * @license lucide-svelte v0.469.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const s=[["path",{d:"M21 12a9 9 0 1 1-9-9c2.52 0 4.93 1 6.74 2.74L21 8"}],["path",{d:"M21 3v5h-5"}]];$(a,h({name:"rotate-cw"},()=>o,{get iconNode(){return s},children:(r,e)=>{var n=c(),d=i(n);f(d,t,"default",{}),p(r,n)},$$slots:{default:!0}}))}export{N as C,x as R,b};
