import{f as s,a as e}from"../chunks/bmn8XlW7.js";import{i as a}from"../chunks/EMQoTJgY.js";import{o as i}from"../chunks/CJbqisBi.js";import{p as m,a as p}from"../chunks/DpkolLiq.js";import{g as n}from"../chunks/C2ETuzsT.js";import{r as f}from"../chunks/CiPTfhJW.js";var v=s('<div class="flex items-center justify-center min-h-[60vh]"><p class="text-muted-foreground">Redirecting to servers...</p></div>');function x(o,r){m(r,!1),i(async()=>{await n(f("/servers"))}),a();var t=v();e(o,t),p()}export{x as component};
