.ssl-item.svelte-1e1dg9t{margin:calc(var(--ssl-gap) / 2);position:relative;list-style:none;-webkit-user-select:none;-moz-user-select:none;user-select:none;backface-visibility:hidden;z-index:1}.ssl-item.svelte-1e1dg9t:not(:has(.ssl-item-handle)),.ssl-item.svelte-1e1dg9t .ssl-item-handle{touch-action:none;cursor:grab}.ssl-item.svelte-1e1dg9t[data-drag-state*=ptr-drag],.ssl-item.svelte-1e1dg9t[data-drag-state*=ptr-drag] .ssl-item-handle{cursor:grabbing}.ssl-item.svelte-1e1dg9t[data-is-locked=true]{cursor:initial}.ssl-item.svelte-1e1dg9t[aria-disabled=true]{cursor:not-allowed}.ssl-item.svelte-1e1dg9t[aria-disabled=true]>*{pointer-events:none}.ssl-item.svelte-1e1dg9t:not([data-drag-state=idle]),.ssl-item.svelte-1e1dg9t:has(~*:not([data-drag-state=idle])),.ssl-item.svelte-1e1dg9t:not([data-drag-state=idle])~*{transition:width var(--ssl-transition-duration),height var(--ssl-transition-duration),margin var(--ssl-transition-duration),transform var(--ssl-transition-duration),z-index var(--ssl-transition-duration)}.ssl-item.svelte-1e1dg9t[data-is-ghost=true]{margin:0;transition:none}.ssl-item.svelte-1e1dg9t:focus,.ssl-item.svelte-1e1dg9t:focus-visible,.ssl-item.svelte-1e1dg9t:focus-within{z-index:2}.ssl-item.svelte-1e1dg9t[data-drag-state*=kbd-drag]{z-index:4}.ssl-item.svelte-1e1dg9t[data-drag-state=kbd-drop],.ssl-item.svelte-1e1dg9t[data-drag-state=kbd-cancel]{z-index:3}.ssl-item.svelte-1e1dg9t[data-drag-state*=ptr]{z-index:0}.ssl-ghost.svelte-ueui03{position:fixed;-webkit-user-select:none;-moz-user-select:none;user-select:none;backface-visibility:hidden;visibility:hidden;z-index:9999}.ssl-ghost.svelte-ueui03[data-ghost-state=ptr-predrop][data-can-clear-on-drag-out=true]:not(:has([data-is-between-bounds=true])),.ssl-ghost.svelte-ueui03[data-ghost-state=ptr-drop]{transition:transform var(--ssl-transition-duration) var(--ssl-transition-easing),z-index 0s var(--ssl-transition-duration)}.ssl-ghost.svelte-ueui03[data-ghost-state=ptr-remove]{transition:z-index 0s var(--ssl-transition-duration)}.ssl-ghost.svelte-ueui03:not([data-ghost-state=idle]){visibility:visible}.ssl-ghost.svelte-ueui03[data-ghost-state*=ptr-drag],.ssl-ghost.svelte-ueui03[data-ghost-state=ptr-predrop]{z-index:10000}.ssl-ghost.svelte-ueui03[data-ghost-state=ptr-drop],.ssl-ghost.svelte-ueui03[data-ghost-state=ptr-remove]{z-index:9999}.ssl-root.svelte-vrcg9u,.ssl-root.svelte-vrcg9u *{box-sizing:border-box}.ssl-root.svelte-vrcg9u{display:flex;flex-wrap:var(--ssl-wrap);padding-inline-start:0;margin:calc(var(--ssl-gap) / 2 * -1)}.ssl-root.svelte-vrcg9u[aria-orientation=vertical]{flex-direction:column}.ssl-root.svelte-vrcg9u[aria-orientation=vertical][data-can-remove-on-drop-out=true] .ssl-item[data-drag-state*=ptr][data-is-between-bounds=false]{margin:0 calc(var(--ssl-gap) / 2)}.ssl-root.svelte-vrcg9u[aria-orientation=horizontal]{flex-direction:row}.ssl-root.svelte-vrcg9u[aria-orientation=horizontal][data-can-remove-on-drop-out=true] .ssl-item[data-is-between-bounds=false]{margin:calc(var(--ssl-gap) / 2) 0}.ssl-root.svelte-vrcg9u[data-can-remove-on-drop-out=true] .ssl-item[data-is-ghost=false][data-drag-state*=ptr]{overflow:hidden}.ssl-live-region.svelte-vrcg9u{position:absolute;left:0;top:0;clip:rect(0px,0px,0px,0px);clip-path:inset(50%);overflow:hidden;white-space:nowrap;width:1px;height:1px}.ssl-root,.ssl-item{list-style:none;padding:0;margin:0}.ssl-item--is-dragged{opacity:.9;z-index:50}.ssl-item--is-drop-target{opacity:.5}
